@@ -42,6 +42,7 @@ from canalyst_candas.utils.transformations import (
 )
 from canalyst_candas.utils.requests import (
     Getter,
+    check_time_series_name,
     get_request,
     create_drivers_dot,
     get_company_info_from_ticker,
@@ -1127,6 +1128,15 @@ class Model:
         if self.csin == "":
             raise CSINEmptyException("Error: CSIN not found")
 
+        if time_series_name != "":
+            self._model_frame = check_time_series_name(
+                self._model_frame,
+                time_series_name,
+                self.api_headers,
+                self.log,
+                self.config.verify_ssl,
+            )
+
         return filter_dataset(
             self._model_frame,
             time_series_name,
