@@ -26,6 +26,7 @@ from canalyst_candas.utils.transformations import (
 from canalyst_candas.utils.requests import (
     get_api_headers,
     send_scenario,
+    check_time_series_name,
 )
 
 plt.style.use("fivethirtyeight")
@@ -698,12 +699,15 @@ class ModelSet:
         DataFrame
 
         """
-
         if ticker != "":
             df = self.models[ticker]._model_frame
         else:
             df = self._features
 
+        df = check_time_series_name(
+            df, time_series_name, self.api_headers, self.log, self.config.verify_ssl
+        )
+
         return filter_dataset(
             df,  # this is the core dataset of the modelset class
             time_series_name,
