@@ -8,13 +8,14 @@ import datetime
 import time
 from io import StringIO, BytesIO
 from urllib.parse import quote_plus
-from typing import Dict, Optional
+from typing import Dict, List, Optional, Union
 
 import pandas as pd
 import boto3
 import requests
 from boto3.session import Session
 from botocore.exceptions import ClientError
+from itertools import product
 from python_graphql_client import GraphqlClient
 from openpyxl import load_workbook
 
@@ -28,6 +29,7 @@ from canalyst_candas import settings
 from canalyst_candas.utils.logger import LogFile
 from canalyst_candas.utils.transformations import (
     _get_mds_bulk_data_url,
+    _get_mds_time_series_url,
     write_json,
     scandir,
     get_api_headers,
@@ -329,6 +331,37 @@ def get_data_set_from_mds(
         return
 
 
+def check_time_series_name(
+    df,
+    time_series_name: Union[str, List[str]],
+    auth_headers: Dict[str, str],
+    log: LogFile,
+    verify_ssl=settings.VERIFY_SSL,
+) -> List[str]:
+    """
+    Checks for additional defined names for a time series
+
+    The user has requested a time series name that exists but is not the first one in the names list
+    """
+    # convert both to list for easier processing
+    csin = df.CSIN.unique().tolist()
+    time_series_name = (
+        [time_series_name] if type(time_series_name) is str else time_series_name
+    )
+    for csin_, ts in product(csin, time_series_name):
+        time_series_url = _get_mds_time_series_url(csin_, ts)
+        names = get_request_json_content(
+            time_series_url, auth_headers, log, verify_ssl
+        )["names"]
+        if names[0] != ts and ts in names:  # valid name that is not the first name
+            df.loc[
+                (df["time_series_name"] == names[0]) & (df["CSIN"] == csin_),
+                "time_series_name",
+            ] = ts
+
+    return df
+
+
 def get_company_info_from_ticker(
     ticker,
     auth_headers,
